===============================
RiboPlot
===============================

.. image:: https://img.shields.io/travis/vimalkumarvelayudhan/riboplot.svg
        :target: https://travis-ci.org/vimalkumarvelayudhan/riboplot

.. image:: https://img.shields.io/pypi/v/riboplot.svg
        :target: https://pypi.python.org/pypi/riboplot


RiboPlot includes programs to plot and output Ribo-Seq read counts from an alignment file (BAM format).

There are two programs in the package:

**riboplot**
    Plot and output read counts (csv) for a single transcript.

**ribocount**
    Output read counts for all transcripts in an alignment.


Free software: GPL license.

Documentation: https://riboplot.readthedocs.org.

